@@ -2,29 +2,32 @@ package Business::CyberSource::Request::Role::BillingInfo;
 use 5.008;
 use strict;
 use warnings;
+use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.2.2'; # VERSION
+our $VERSION = 'v0.2.3'; # VERSION
 
 use Moose::Role;
-use namespace::autoclean;
 use MooseX::Aliases;
 use MooseX::Types::Varchar         qw( Varchar       );
 use MooseX::Types::Email           qw( EmailAddress  );
 use MooseX::Types::Locale::Country qw( Alpha2Country );
+use MooseX::Types::NetAddr::IP     qw( NetAddrIPv4   );
 
 has first_name => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[60],
-	documentation => 'Card Holder\'s first name',
+	documentation => 'Customer\'s first name.The value should be the same as '
+		. 'the one that is on the card.',
 );
 
 has last_name => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[60],
-	documentation => 'Card Holder\'s last name',
+	documentation => 'Customer\'s last name. The value should be the same as '
+		. 'the one that is on the card.'
 );
 
 has street => (
@@ -32,7 +35,8 @@ has street => (
 	is       => 'ro',
 	isa      => Varchar[60],
 	alias    => 'street1',
-	documentation => 'Street address on credit card billing statement',
+	documentation => 'First line of the billing street address as it '
+		. 'appears on the credit card issuer\'s records. alias: C<street1>',
 );
 
 has street2 => (
@@ -46,14 +50,16 @@ has city => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[50],
-	documentation => 'City on credit card billing statement',
+	documentation => 'City of the billing address.',
 );
 
 has state => (
-	required => 1,
+	required => 0,
+	alias    => 'province',
 	is       => 'ro',
 	isa      => Varchar[2],
-	documentation => 'State on credit card billing statement',
+	documentation => 'State or province of the billing address. '
+		. 'Use the two-character codes. alias: C<province>',
 );
 
 has country => (
@@ -66,10 +72,13 @@ has country => (
 );
 
 has zip => (
-	required => 1,
+	required => 0,
+	alias    => 'postal_code',
 	is       => 'ro',
 	isa      => Varchar[10],
-	documentation => 'postal code on credit card billing statement',
+	documentation => 'Postal code for the billing address. '
+		. 'The postal code must consist of 5 to 9 digits. '
+		. 'alias: C<postal_code>',
 );
 
 has email => (
@@ -82,28 +91,39 @@ has email => (
 
 has ip => (
 	required => 0,
+	alias    => 'ip_address',
+	coerce   => 1,
 	is       => 'ro',
-	isa      => Varchar[15],
-	documentation => 'IP address that customer submitted transaction from',
+	isa      => NetAddrIPv4,
+	documentation => 'Customer\'s IP address. alias: C<ip_address>',
 );
 
 sub _billing_info {
 	my $self = shift;
 
-	my $bi = {
+	my $i = {
 		firstName  => $self->first_name,
 		lastName   => $self->last_name,
 		street1    => $self->street1,
 		street2    => $self->street2,
 		city       => $self->city,
-		state      => $self->state,
-		postalCode => $self->zip,
 		country    => $self->country,
 		email      => $self->email,
-		ipAddress  => $self->ip,
 	};
 
-	return $bi;
+	if ( $self->ip ) {
+		$i->{ipAddress} = $self->ip->addr;
+	}
+
+	if ( $self->state ) {
+		$i->{state} = $self->state;
+	}
+
+	if ( $self->zip ) {
+		$i->{postalCode} = $self->zip,
+	}
+
+	return $i;
 }
 
 1;
@@ -119,7 +139,7 @@ Business::CyberSource::Request::Role::BillingInfo - Role for requests that requi
 
 =head1 VERSION
 
-version v0.2.2
+version v0.2.3
 
 =head1 BUGS
 
