@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.2.2'; # VERSION
+our $VERSION = 'v0.2.3'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -20,12 +20,15 @@ has decision => (
 	required => 1,
 	is       => 'ro',
 	isa      => Decision,
+	documentation => 'Summarizes the result of the overall request',
 );
 
 has reason_code => (
 	required => 1,
 	is       => 'ro',
 	isa      => Int,
+	documentation => 'Numeric value corresponding to the result '
+		. 'of the credit card authorization request',
 );
 
 has reason_text => (
@@ -34,6 +37,10 @@ has reason_text => (
 	is       => 'ro',
 	isa      => Str,
 	builder  => '_build_reason_text',
+	documentation => 'official description of returned reason code. '
+		. 'warning: reason codes are returned by CyberSource and '
+		. 'occasionally do not reflect the real reason for the error '
+		. 'please inspect the trace request/response for issues',
 );
 
 sub _build_reason_text {
@@ -126,6 +133,7 @@ __PACKAGE__->meta->make_immutable;
 
 # ABSTRACT: Response Object
 
+
 __END__
 =pod
 
@@ -135,7 +143,18 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version v0.2.2
+version v0.2.3
+
+=head1 DESCRIPTION
+
+Every time you call C<submit> on a request object it returns a response
+object. This response can be used to determine the success of a transaction,
+as well as receive a follow up C<request_id> in case you need to do further
+actions with this. A response will always have C<decision>, C<reason_code>,
+C<reason_text>, and C<request_id> attributes. You should always use either
+introspection or check the C<decision> to determine which attributes will be
+defined, as what is returned by CyberSource varies depending on what the
+C<decision> is and what was sent in the request itself.
 
 =head1 ATTRIBUTES
 
@@ -155,6 +174,8 @@ Type: Str
 
 This attribute is required.
 
+Additional documentation: official description of returned reason code. warning: reason codes are returned by CyberSource and occasionally do not reflect the real reason for the error please inspect the trace request/response for issues
+
 =head2 decision
 
 Reader: decision
@@ -163,6 +184,8 @@ Type: MooseX::Types::CyberSource::Decision
 
 This attribute is required.
 
+Additional documentation: Summarizes the result of the overall request
+
 =head2 reason_code
 
 Reader: reason_code
@@ -171,6 +194,42 @@ Type: Int
 
 This attribute is required.
 
+Additional documentation: Numeric value corresponding to the result of the credit card authorization request
+
+=head1 TRAITS
+
+=head2 Accept
+
+This trait is applied if the decision is C<ACCEPT>.
+
+=head3 amount
+
+Type: Num
+
+Amount that was approved.
+
+=head3 datetime
+
+Type: MooseX::Types::DateTime::W3C::DateTimeW3C
+
+A response timestamp (will probably become a DateTime object at some point)
+
+=head3 reference_code
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+The merchant reference code originally sent
+
+=head2 Reject
+
+This trait is applied if the decision is C<Reject>
+
+=head3 request_token
+
+The field is an encoded string that contains no confidential information,
+such as an account number or card verification number. The string can contain
+up to 256 characters.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
